@@ -79,7 +79,7 @@ public static class FAudio
 
 	public const uint FAUDIO_ABI_VERSION =		 0;
 	public const uint FAUDIO_MAJOR_VERSION =	24;
-	public const uint FAUDIO_MINOR_VERSION =	 6;
+	public const uint FAUDIO_MINOR_VERSION =	 7;
 	public const uint FAUDIO_PATCH_VERSION =	 0;
 
 	public const uint FAUDIO_COMPILED_VERSION = (
@@ -1952,7 +1952,7 @@ public static class FAudio
 	[StructLayout(LayoutKind.Sequential, Pack = 1)]
 	public struct F3DAUDIO_DISTANCE_CURVE
 	{
-		IntPtr pPoints; /* F3DAUDIO_DISTANCE_CURVE_POINT* */
+		public IntPtr pPoints; /* F3DAUDIO_DISTANCE_CURVE_POINT* */
 		public uint PointCount;
 	}
 
